@@ -161,10 +161,12 @@ rstto_settings_init (GObject *object)
     settings->priv->show_nav_toolbar = TRUE;
     settings->priv->open_entire_folder = TRUE;
     settings->priv->window_width = 600;
-    settings->priv->window_height = 400;
+    settings->priv->window_height = 440;
     settings->priv->wrap_images = TRUE;
+    settings->priv->show_thumbnailbar = TRUE;
     settings->priv->use_thunar_properties = TRUE;
     settings->priv->maximize_on_startup = TRUE;
+    settings->priv->hide_thumbnailbar_fullscreen = TRUE;
 
     xfconf_g_property_bind (settings->priv->channel, "/window/width", G_TYPE_UINT, settings, "window-width");
     xfconf_g_property_bind (settings->priv->channel, "/window/height", G_TYPE_UINT, settings, "window-height");
